# 💡 Description

Project Bluebear: An Improved Cell-Free TxTl System

## Background

Cell-free transcription and translation (TXTL) is a promising tool for rapid prototyping, component production, and testing in point-of-care or remote locations [1]. It allows the production of biomolecules directly from DNA code using cytosol constituents and biochemical energy components. However, several challenges limit its widespread adoption:

1. Cell lysate and energy solutions require cryogenic storage (-80°C) to remain usable.
2. Linear DNA templates are quickly degraded by endogenous DNases.
3. Specialized equipment is needed for lysate production.

Previous research has addressed these issues separately:

- Lyoprotectants have been used to freeze-dry lysate and energy buffer, but with negative effects on TXTL efficiency [1].
- Linear DNA protection has been achieved using decoy molecules or DNA mimic proteins [2].
- A strain with the major DNase complex deleted from the bacterial genome has been developed [3].
- A plasmid expressing a viral endolysis protein has been created for easier cell lysis [4].

## Project Goals

The main goal of this project is to create and compare different Autolysate strains that incorporate multiple solutions to the aforementioned problems. The project aims to:

1. Increase lysate stability through:
    - A nuclease-free E. coli strain
    - Incorporation of IDP-generating tardigrade genes
2. Reduce lysate costs by:
    - Including a viral autolysis plasmid
    - Employing alternative energy solutions
    - Using cost-effective desiccation methods

## Tardigrade Genetics

The project draws inspiration from tardigrades, microscopic animals known for their resilience to extreme conditions. Tardigrades can survive vacuums, freezing temperatures, dehydration, and radiation thanks to genes that produce intrinsically disordered proteins (IDPs). These IDPs protect their cells from extreme conditions, allowing the body to go dormant while maintaining cellular architecture.

## Research Plan

1. Transform the Autolysate plasmid into the BL21 ΔrecBCD strain (addgene #176581) and test for effective protection of linear DNA templates.
2. Clone an inducible T7 RNA polymerase gene into the Autolysate plasmid and test functionality (optional).
3. Clone synthesized gene fragments from tardigrades (genes no. 107838, 106094, and 94063) into the Autolysate plasmid [5]. Test desiccation resistance of created strains vs. the original strain.
4. Compare effective lyoprotection following the methods from Guzman-Chavez [1].

## Applications

### Human Practices Applications

1. Biosensors for Heavy Metals: Cell-free systems can be engineered to react to a range of compounds, addressing the issue of high heavy metal concentrations in soil and water.
2. Educational Kits for Schools: Dried cell-free lysate is easy to use without specialized knowledge, creating opportunities to teach children about biology.
3. On-site Medicinal Production: Areas lacking traditional drug development infrastructure can use properly prepared and stored lysate to synthesize non-shelf-stable medicines such as hormones or vaccines.

### Commercial Applications

Cell-Free Protein Synthesis has enormous potential in prototyping new organic compounds. The improved stability and reduced costs resulting from this research could provide an edge in the market, particularly for high-value compounds such as pharmaceuticals.

## Relevance

Completion of this work would result in new strains for autolysate production with built-in biological solutions to major barriers in biosynthetic production using TXTL. Their native ability to accept PCR templates, combined with ease of production and extended stability, should make them an attractive resource for rapid prototyping and custom small molecule production.

## References

[1] F. Guzman-Chavez u. a., "Constructing Cell-Free Expression Systems for Low-Cost Access", ACS Synth. Biol., Bd. 11, Nr. 3, S. 1114–1128, März 2022, doi: 10.1021/acssynbio.1c00342.

[2] R. Marshall, C. S. Maxwell, S. P. Collins, C. L. Beisel, und V. Noireaux, "Short DNA containing χ sites enhances DNA stability and gene expression in E. coli cell-free transcription–translation systems", Biotechnol. Bioeng., Bd. 114, Nr. 9, S. 2137–2141, 2017, doi: 10.1002/bit.26333.

[3] M. Sabeti Azad, A. Cardoso Batista, J.-L. Faulon, C. L. Beisel, J. Bonnet, und M. Kushwaha, "Cell-Free Protein Synthesis from Exonuclease-Deficient Cellular Extracts Utilizing Linear DNA Templates", J. Vis. Exp., Nr. 186, S. 64236, Aug. 2022, doi: 10.3791/64236.

[4] A. Didovyk, T. Tonooka, L. Tsimring, und J. Hasty, "Rapid and Scalable Preparation of Bacterial Lysates for Cell-Free Gene Expression", ACS Synth. Biol., Bd. 6, Nr. 12, S. 2198–2208, Dez. 2017, doi: 10.1021/acssynbio.7b00253.

[5] T. C. Boothby u. a., "Tardigrades Use Intrinsically Disordered Proteins to Survive Desiccation", Mol. Cell, Bd. 65, Nr. 6, S. 975-984.e5, März 2017, doi: 10.1016/j.molcel.2017.02.018.