# 🦺 Safety

Safety should be an integral component of synthetic biology. We believe that not only have we achieved working under safe conditions, but with our work, we can enable more teams and more groups of people to do the same by helping the broad adoption of cell-free systems into their workflows.
Cell lysates have some special characteristics in terms of safety:
* Reduced risk of contamination
* Cell-based systems have the risk of “escaping,” which could impact human health and the environment. In contrast, this risk is reduced in cell-free systems (Lee et al., 2018) and almost eliminated with filter sterilization.
* No self-replication

Unlike cell systems, cell lysates cannot self-replicate. This eliminates the risk of uncontrolled growth or proliferation of engineered cells, which reduces the limitations on the applications of synthetic biology tools.

## Controlled Environment for reactions
Working with cell lysates allows for better control of the environment in which the biochemical reactions take place, which can further reduce the risk of complications that can arise from cellular metabolism and the likelihood of unintentional byproduct interaction.
This, in place, brings forth several advantages:
## Simplified Handling
Since cell lysates don’t require the level of containment of living cells, they can be more easily transported and used in diverse settings. This allows applications in educational environments and in the field.
## Minimized regulatory burden
Cell systems often require extensive safety assessments and containment measures. The absence of living organisms can facilitate faster development and deployment of biotechnological applications.
Tinafar, A., Jaenes, K., & Pardee, K. (2019). Synthetic Biology Goes Cell-Free. BMC Biology, 17. https://doi.org/10.1186/s12915-019-0685-x
Lee, J. W., Chan, C. T., Slomovic, S., & Collins, J. J. (2018). Next-generation biocontainment systems for engineered organisms. Nature Chemical Biology, 14(6), 530-537. https://doi.org/10.1038/s41589-018-0056-x

## Risk mitigation
Working with synthetic biology in a controlled environment, like our lab, is very different from working as a technician in the field or working as a professor in a classroom full of students giving a lesson. In the lab, surfaces and materials are routinely disinfected, and the contact of the lab’s contents with the outside is carefully handled. The release of genetically modified organisms and their products represents a significant risk to humans, food sources, and the environment, which is why their manipulation is relatively inaccessible.

According to the American National Institute of Health, a GMO escapee rate below 1 in 108 cells is considered to be acceptably safe (Wilson, 1993). We knew that using cell lysates already reduced the risk of GMO release, but we wanted to confirm it was failure-free.
Since a significant part of our vision involved bringing our lysate out of the lab, and allowing other teams to use it, accidental release was an important risk to address to ensure the safety of our product.

To evaluate the presence of bacteria in our lysates, we inoculated two LB plates with undiluted aliquotes of 30 ul each. There was a single CFU in both plates, which was initially promising, but after discussions with the iGEM safety committee, it was clear that we needed to take a step further to sterilize our lysate.

Filter sterilization had been initially suggested by our advisors, and it was confirmed as a viable strategy by literature. After a visit to Invitris, a Startup from the 2018 iGEM runner-up project and one of our significant collaborators, they provided us with industry-level sterility tests, based on rezarsurin reduction and MPN (Most Probable Number) protocols to confirm the sterility of the samples we would ship.

After speaking with the safety committee and professionals in the industry, we implemented filter sterilization with a 0.2 um filter, and a sterility test step on every batch of lysate we made that was intended for freeze drying and shipment.

Wilson, D. J. (1993). NIH guidelines for research involving recombinant DNA molecules. Accountability in Research, 3(2–3), 177–185. https://doi.org/10.1080/08989629308573848
Lee, J. W., Chan, C. T., Slomovic, S., & Collins, J. J. (2018). Next-generation biocontainment systems for engineered organisms. Nature Chemical Biology, 14(6), 530-537. https://doi.org/10.1038/s41589-018-0056-x


