// @ts-check
// `@type` JSDoc annotations allow editor autocompletion and type checking
// (when paired with `@ts-check`).
// There are various equivalent ways to declare your Docusaurus config.
// See: https://docusaurus.io/docs/api/docusaurus-config

import { themes as prismThemes } from 'prism-react-renderer';

/** @type {import('@docusaurus/types').Config} */
const config = {
  title: 'Bluebear',
  tagline: 'Cell-Free for All',
  favicon: 'https://static.igem.wiki/teams/5286/favicon.png',

  clientModules: [
    // TODO: Add custom css and js here.
  ],

  // Set the production url of your site here
  url: 'https://2024.igem.wiki',
  // Set the /<baseUrl>/ pathname under which your site is served
  // For GitHub pages deployment, it is often '/<projectName>/'
  baseUrl: '/tum-straubing/',

  // GitHub pages deployment config.
  // If you aren't using GitHub pages, you don't need these.
  organizationName: 'igem', // Usually your GitHub org/user name.
  projectName: 'TUM-Straubing', // Usually your repo name.

  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',

  // Even if you don't use internalization, you can use this field to set useful
  // metadata like html lang. For example, if your site is Chinese, you may want
  // to replace "en" with "zh-Hans".
  i18n: {
    defaultLocale: 'en',
    locales: ['en'],
  },

  presets: [
    [
      'classic',
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: {
          sidebarPath: require.resolve('./sidebars.js'),
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          editUrl: 'https://gitlab.igem.org/2024/tum-straubing/tree/main/',
          routeBasePath: '/',
        },
        theme: {
          customCss: require.resolve('./src/css/custom.css'),
        },
      }),
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      // Replace with your project's social card
      image: 'img/socialcard.png',

      colorMode: {
        defaultMode: 'light',
        disableSwitch: true,
        respectPrefersColorScheme: false,
      },

      prism: {
        //theme: prismThemes.github,
        theme: prismThemes.dracula,
        darkTheme: prismThemes.dracula,
      },

      navbar: {
        title: 'Bluebear',
        logo: {
          alt: 'Bluebear Logo',
          src: 'https://static.igem.wiki/teams/5286/bluebear-no-text.svg',
        },
        items: [
          {
            href: 'https://gitlab.igem.org/2024/tum-straubing',
            label: 'GitLab',
            position: 'right',
          },

          {
            position: 'left',
            label: 'Project',
            items: [
              
            
              {
                label: 'Description',
                to: '/description',
              },
              {
                label: 'Engineering',
                to: '/engineering',
              },
              {
                label: 'Results',
                to: '/results',
              },
            ]
          },
          {
            position: 'left',
            label: 'Lab',
            items: [
              {
                label: 'Safety',
                to: '/safety',
              },
              {
                label: 'Protocols',
                to: '/protocols',
              },
              {
                label: 'Notebook',
                to: '/notebook',
              },
              {
                label: 'Part Collection',
                to: '/part-collection',
              },
            
            ]

            
          },
          {
            position: 'left',
            label: 'Human Practices',
            items: [
              {
                label: 'Integrated Human Practices',
                to: '/human-practices',
              },
              {
                label: 'Entrepreneurship',
                to: '/entrepreneurship',
              },
              {
                label: 'Education',
                to: '/education',
              },

            ]
            
          },
          {
            position: 'left',
            label: 'Team',
            items: [
              {
                label: 'Team',
                to: '/team',
              },
              {
                label: 'Attributions',
                to: '/attributions',
              },
              {
                label: 'Collaborations',
                to: '/collaborations',
              },
            ]
          },
          {
            position: 'left',
            label: 'Competition',
            items: [
              {
                label: 'Medal Criteria',
                to: '/medals',
              },
              {
                label: 'Awards',
                to: '/awards',
              },
            ]
          }

        ],
      },
      footer: {
        style: 'dark',
        links: [
          {
            title: 'More information',
            items: [
              {
                label: 'Instagram',
                href: 'https://www.instagram.com/igem.straubing'
              },
              {
                label: 'Twitter',
                href: 'https://twitter.com/straubingigem'
              },
              {
                label: 'Wiki Source',
                href: 'https://gitlab.igem.org/2024/tum-straubing',
              },
            ],
          },
        ],
        copyright: `Created by 2024 iGEM Straubing. The contents of this website are free to use under the <a href='https://creativecommons.org/licenses/by/4.0/' target='_blank'><b>Creative Commons Attribution 4.0 international</b></a> license. Built with Docusaurus.`,
      },
    }),
};

module.exports = config;
