import React, { useState } from 'react';
import styled from 'styled-components';

const FrameContainer = styled.div`
  display: inline-block;
  margin: 0.5em 0;
  width: 100%;
  max-width: 100%;
`;

const ImageContainer = styled.div`
  overflow: hidden;
  border-radius: 10px;
  cursor: pointer;
  transition: transform 0.3s ease;

  &:hover {
    transform: scale(1.02);
  }
`;

const Image = styled.img`
  display: block;
  width: 100%;
  height: auto;
  object-fit: cover;
`;

const Caption = styled.div`
  text-align: center;
  margin-top: 8px;
  font-style: italic;
  color: #666;
  font-size: 0.9em;
`;

const ExpandedPhoto = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.8);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 1000;
`;

const ExpandedImage = styled.img`
  max-width: 90%;
  max-height: 90%;
  object-fit: contain;
`;

const PictureFrame = ({ src, alt, caption }) => {
  const [isExpanded, setIsExpanded] = useState(false);

  const handleImageClick = () => {
    setIsExpanded(true);
  };

  const handleCloseExpanded = () => {
    setIsExpanded(false);
  };

  return (
    <>
      <FrameContainer>
        <ImageContainer onClick={handleImageClick}>
          <Image src={src} alt={alt} />
        </ImageContainer>
        {caption && <Caption>{caption}</Caption>}
      </FrameContainer>
      {isExpanded && (
        <ExpandedPhoto onClick={handleCloseExpanded}>
          <ExpandedImage src={src} alt={alt} />
        </ExpandedPhoto>
      )}
    </>
  );
};

export default PictureFrame;