import React, { useState, useRef } from 'react';
import useBaseUrl from '@docusaurus/useBaseUrl';
import styles from './TeamGallery.module.css';

const TeamMemberCard = ({ name, role, image, onClick }) => (
  <div className={styles.teamMemberCard} onClick={onClick}>
    <div className={styles.imageWrapper}>
      <img src={useBaseUrl(image)} alt={name} className={styles.teamMemberImage} />
    </div>
    <h3 className={styles.teamMemberName}>{name}</h3>
    <p className={styles.teamMemberRole}>{role}</p>
  </div>
);

const TeamMemberPopup = ({ member, isOpen, onClose }) => (
  isOpen && (
    <div className={styles.popupOverlay} onClick={onClose}>
      <div className={styles.popupContent} onClick={(e) => e.stopPropagation()}>
        <div className={styles.popupImageWrapper}>
          <img src={useBaseUrl(member.image)} alt={member.name} className={styles.popupImage} />
        </div>
        <h2 className={styles.popupName}>{member.name}</h2>
        <h3 className={styles.popupRole}>{member.role}</h3>
        <p className={styles.popupBio}>{member.bio}</p>
        <button className={styles.popupCloseButton} onClick={onClose}>Close</button>
      </div>
    </div>
  )
);

const TeamGallery = ({ people, title }) => {
  const [selectedMember, setSelectedMember] = useState(null);
  const scrollContainer = useRef(null);

  const scroll = (scrollOffset) => {
    if (scrollContainer.current) {
      scrollContainer.current.scrollBy({ left: scrollOffset, behavior: 'smooth' });
    }
  };

  return (
    <div className={styles.teamGalleryContainer}>
      {title && <h2 className={styles.galleryTitle}>{title}</h2>}
      <div className={styles.teamGallery} ref={scrollContainer}>
        {people.map((person, index) => (
          <TeamMemberCard 
            key={index} 
            {...person} 
            onClick={() => setSelectedMember(person)}
          />
        ))}
      </div>
      
      <button className={`${styles.scrollButton} ${styles.scrollLeft}`} onClick={() => scroll(-200)}>
        &#8249;
      </button>
      <button className={`${styles.scrollButton} ${styles.scrollRight}`} onClick={() => scroll(200)}>
        &#8250;
      </button>
      <TeamMemberPopup 
        member={selectedMember} 
        isOpen={!!selectedMember} 
        onClose={() => setSelectedMember(null)}
      />
    </div>
  );
};


export default TeamGallery;