import React, { useState } from 'react';
import styled from 'styled-components';

const CollageContainer = styled.div`
  display: grid;
  grid-template-columns: repeat(auto-fill, minmax(100px, 1fr));
  gap: 8px;
`;

const PhotoTile = styled.img`
  width: 100%;
  height: 100%;
  object-fit: cover;
  border-radius: 4px;
  cursor: pointer;
  transition: transform 0.3s ease;

  &:hover {
    transform: scale(1.05);
  }
`;

const ExpandedPhoto = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.8);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 1000;
`;

const ExpandedImage = styled.img`
  max-width: 90%;
  max-height: 90%;
  object-fit: contain;
`;

const PhotoCollage = ({ photos }) => {
  const [expandedPhoto, setExpandedPhoto] = useState(null);

  const handlePhotoClick = (photo) => {
    setExpandedPhoto(photo);
  };

  const handleCloseExpanded = () => {
    setExpandedPhoto(null);
  };

  return (
    <>
      <CollageContainer>
        {photos.map((photo, index) => (
          <PhotoTile
            key={index}
            src={photo}
            alt={`Photo ${index + 1}`}
            onClick={() => handlePhotoClick(photo)}
          />
        ))}
      </CollageContainer>
      {expandedPhoto && (
        <ExpandedPhoto onClick={handleCloseExpanded}>
          <ExpandedImage src={expandedPhoto} alt="Expanded photo" />
        </ExpandedPhoto>
      )}
    </>
  );
};

export default PhotoCollage;